'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convert = convert;
exports.wrapSchema = wrapSchema;
exports.convertSchema = convertSchema;
exports.convertClassName = convertClassName;
exports.convertFieldGroups = convertFieldGroups;
exports.convertFieldsets = convertFieldsets;
exports.convertFields = convertFields;
exports.convertObjectArray = convertObjectArray;

var _promise = require('promise');

var _promise2 = _interopRequireDefault(_promise);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _validate = require('./validate');

var _renderer = require('./renderer');

var _transforms = require('./transforms');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function convert(uis1, outfile, logger) {
  return convertSchema(uis1, logger).then(function (uis2) {
    logger.log(uis2);
    return wrapSchema(uis2, logger);
  }).then(function (uis2) {
    logger.log('attempting to validate view');
    return (0, _validate.validateView)(uis2, logger).then(function (result) {
      return result[0];
    });
  });
}

function wrapSchema(uis2) {
  return _promise2.default.resolve({
    type: 'form',
    version: '2.0',
    cells: [{
      classNames: uis2.classNames,
      children: uis2.children
    }]
  });
}

function convertSchema(ui1, logger) {
  var newObj = {};
  logger.log('converting...');
  return convertClassName(ui1, newObj, logger).then(function (ui2) {
    return convertFieldGroups(ui1, ui2, logger);
  });
}

function convertClassName(ui1, ui2, logger) {
  logger.log('converting class name');
  var key = _lodash2.default.keys(ui1)[0];
  ui2.classNames = {
    cell: ui1[key].cssClass || ''
  };
  return _promise2.default.resolve(ui2);
}

function convertFieldGroups(ui1, ui2, logger) {
  logger.log('converting field groups');
  var key = _lodash2.default.keys(ui1)[0];
  logger.log(ui1);
  var fgs = ui1[key].fieldGroups || [];
  var children = fgs.map(function (fg) {
    var fields = convertFields(fg.fields, logger).concat(convertFieldsets(fg.fieldsets, logger));
    return {
      'label': fg.name || '',
      'children': fields
    };
  });
  ui2.children = children;
  return _promise2.default.resolve(ui2);
}

function convertFieldsets(fieldsets, logger) {
  logger.log('converting fieldsets');
  return _lodash2.default.map(fieldsets, function (fieldset, key) {
    logger.log('key: ' + key);
    return {
      model: key.split('_').join(''),
      label: fieldset.label || '',
      description: fieldset.description || fieldset.help || '',
      collapsible: fieldset['switch'] || true,
      children: convertFields(fieldset.fields, logger)
    };
  });
}

function convertFields(fields, logger) {
  logger.log('converting fields...');
  return _lodash2.default.map(fields, function (field, key) {
    var newField = {
      model: key,
      label: field.label || '',
      description: field.description || field.help || ''
    };
    if (field.type === 'objectarray') {
      newField.arrayOptions = convertObjectArray(field, logger);
      logger.log(newField.arrayOptions);
    }
    var placeholder = field.placeholder || field.prompt;
    if (placeholder) _lodash2.default.extend(newField, { placeholder: placeholder });
    (0, _transforms.setTransforms)(newField, field, logger);
    var result = (0, _renderer.setRenderer)(newField, field, logger);
    return result;
  });
}

function convertObjectArray(field, logger) {
  var result = {
    autoAdd: true,
    compact: true,
    showLabel: false,
    sortable: true
  };
  if (field.order) {
    result.itemCell = {
      children: _lodash2.default.map(field.order.split(','), function (prop) {
        return { model: prop };
      })
    };
  }
  return result;
}