'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isViewFile = isViewFile;
exports.isModelFile = isModelFile;
exports.parseJSON = parseJSON;
exports.readFile = readFile;
exports.writeFile = writeFile;
exports.getDefaultOutputPath = getDefaultOutputPath;
exports.getLegacyViewType = getLegacyViewType;
var fsp = require('fs-promise');
var _ = require('lodash');
var strings = require('../assets/strings');

function isViewFile(pojo) {
  return pojo.type === 'detail' || pojo.type === 'form' && pojo.version.indexOf('2.') !== -1;
}

function isModelFile(pojo) {
  return pojo.type === 'object' && pojo.properties;
}

function parseJSON(string) {
  var results = void 0;
  try {
    results = JSON.parse(string);
  } catch (err) {
    return Promise.reject(strings.strings.conversion.errors.invalidJson);
  }
  return Promise.resolve(results);
}

function readFile(file) {
  return fsp.readFile(file, 'utf8');
}

function writeFile(outfile, data) {
  return fsp.writeFile(outfile, JSON.stringify(data, null, 2) + '\n').then(function () {
    return data;
  });
}

function getDefaultOutputPath(inputPath) {
  return inputPath.split('.')[0] + '-uis2.json';
}

function getLegacyViewType(view) {
  if (view.type === 'form' || view.type === 'detail') {
    return Promise.resolve('bv1');
  }
  if (_.keys(view)[0] && _.keys(view)[0].split('.').length === 3) {
    return Promise.resolve('uis1');
  }
  return Promise.reject(strings.strings.conversion.errors.noViewType);
}