'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validate = validate;
exports.validateView = validateView;
exports.validateModel = validateModel;
exports.validateViewWithModel = validateViewWithModel;

var _v = require('bunsen-core/lib/validator/view-schemas/v2');

var _v2 = _interopRequireDefault(_v);

var _zSchema = require('z-schema');

var _zSchema2 = _interopRequireDefault(_zSchema);

var _utils = require('../lib/utils');

var _model = require('bunsen-core/lib/validator/model');

var _promise = require('promise');

var _promise2 = _interopRequireDefault(_promise);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var zSchemaValidator = new _zSchema2.default();
// import {validate as viewValidator} from 'bunsen-core/lib/validator/index'
function validate(inFile, optionalFile, logger) {
  return (0, _utils.readFile)(inFile).then(function (infileJSON) {
    logger.log('read file');
    return (0, _utils.parseJSON)(infileJSON).catch(function (err) {
      logger.error('Parsing JSON: ' + err);
    });
  }).then(function (pojo) {
    logger.log('parsed file');
    if ((0, _utils.isModelFile)(pojo)) {
      logger.info('detected model file');
      if (optionalFile) {
        return (0, _utils.readFile)(optionalFile).then(function (viewJSON) {
          return (0, _utils.parseJSON)(viewJSON).catch(function (err) {
            logger.error(JSON.stringify(err, null, 2));
          });
        }).then(function (view) {
          return validateViewWithModel(view, pojo);
        });
      }
      return validateModel(pojo, logger);
    }
    if ((0, _utils.isViewFile)(pojo)) {
      logger.info('detected bunsen view file');
      return validateView(pojo).catch(function (errors) {
        logger.error(JSON.stringify(errors, null, 2));
      });
    }
    return _promise2.default.reject('<viewOrModelFile> must be a valid Bunsen view or Bunsen Model');
  });
}

function validateView(ui2) {
  zSchemaValidator.validate(ui2, _v2.default);
  if (zSchemaValidator.getLastErrors()) {
    return _promise2.default.reject(zSchemaValidator.getLastErrors());
  }
  return _promise2.default.resolve([ui2, 'valid Bunsen View']);
}

function validateModel(model, logger) {
  var results = (0, _model.validate)(model);
  if (results.errors && results.errors.length) {
    return _promise2.default.reject(results.errors);
  }
  if (results.warnings && results.warnings.length) {
    logger.warn(results.warnings);
  }
  return _promise2.default.resolve([model, 'valid Bunsen Model']);
}

function validateViewWithModel(view, model, logger) {
  // const results = viewValidator(view, model, [{}, {}], this)
  var results = {};
  if (results.errors && results.errors.length) {
    return _promise2.default.reject(results.errors);
  }
  if (results.warnings && results.warnings.length) {
    logger.warn(results.warnings);
  }
  return _promise2.default.resolve(view);
}